@@ -125,7 +125,10 @@ class HTMLRenderer(HTMLParser):
         if tag in self.block_tags:
             self.end_para(tag)
         if tag == 'a':
-            content = ''.join(self.href_content)
+            if self.href_content:
+                content = ''.join(self.href_content)
+            else:
+                content = None
             self.href_content = None
             if content and self.last_href and content != self.last_href:
                 self.handle_data(' <%s>' % self.last_href)
@@ -154,6 +157,12 @@ class HTMLRenderer(HTMLParser):
             self.href_content.append(data)
 
     def handle_entityref(self, name):
+        name = name.lower()
+        if name not in htmlentitydefs.entitydefs:
+            # bad entity, just let it through
+            # (like a &var=value in a URL)
+            self.handle_data('&'+name)
+            return
         result = htmlentitydefs.entitydefs[name]
         if result.startswith('&'):
             self.handle_charref(result[2:-1])
